==> mjml-head-4.1.1.jar: META-INF/resources/webjars/mjml-head/4.1.1/lib/index.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _mjmlCore = require('mjml-core');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MjHead = function (_HeadComponent) {
  (0, _inherits3.default)(MjHead, _HeadComponent);

  function MjHead() {
    (0, _classCallCheck3.default)(this, MjHead);
    return (0, _possibleConstructorReturn3.default)(this, (MjHead.__proto__ || (0, _getPrototypeOf2.default)(MjHead)).apply(this, arguments));
  }

  (0, _createClass3.default)(MjHead, [{
    key: 'handler',
    value: function handler() {
      this.handlerChildren();
    }
  }]);
  return MjHead;
}(_mjmlCore.HeadComponent);

exports.default = MjHead;
module.exports = exports['default'];

==> mjml-head-4.4.1.jar: META-INF/resources/webjars/mjml-head/4.4.1/lib/index.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _mjmlCore = require('mjml-core');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MjHead = function (_HeadComponent) {
  (0, _inherits3.default)(MjHead, _HeadComponent);

  function MjHead() {
    (0, _classCallCheck3.default)(this, MjHead);
    return (0, _possibleConstructorReturn3.default)(this, (MjHead.__proto__ || (0, _getPrototypeOf2.default)(MjHead)).apply(this, arguments));
  }

  (0, _createClass3.default)(MjHead, [{
    key: 'handler',
    value: function handler() {
      return this.handlerChildren();
    }
  }]);
  return MjHead;
}(_mjmlCore.HeadComponent);

exports.default = MjHead;
module.exports = exports['default'];
